.. ngs-tools documentation master file, created by
   sphinx-quickstart on Mon Feb  1 11:20:21 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ngs-tools: Reusable tools for working with next-generation sequencing (NGS) data
================================================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   API <autoapi/ngs_tools/index>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
